// Enforce use of a strict operating context.
'use strict';

// Define handler for this plugin.
const plugin = (server, options, next) => {

  // Use app dependency container.
  const container = options.container;

  // Resolve dependencies from app container.
  container.resolve((config, peers, Boom) => {

    // Core dependencies required before trying to load this plugin.
    server.dependency(peers(__dirname), (server, next) => {

      // Register plugin views.
      server.registerPluginViews(__dirname);

      // Attach plugin route(s) to admin server.
      server.select('admin').route([
        {
          method: 'GET',
          path: '/instance',
          handler: (request, reply) => {

            reply.view('index', null, { layout: 'default' });
          }
        }
      ]);

      // Attach plugin route(s) to api server.
      server.select('api').route([
        {
          method: 'GET',
          path: '/instance',
          handler: (request, reply) => {

            server.store().Core.Instance.Instance
              .findAll({
                with: (request.query.with) ? request.query.with.split(',') : null
              })
              .then((instances) => {

                const instance = instances[0];
                reply({ instance });
              })
              .catch((error) => reply(Boom.badRequest(error)));
          }
        },
        {
          method: 'PUT',
          path: '/instance',
          handler: (request, reply) => {

            const Instance = server.store().Core.Instance.Instance;
            Instance
              .findAll()
              .then((instances) => {

                const instance = instances[0];
                Instance
                  .update(instance.id, request.payload)
                  .then((instance) => reply({ instance }))
                  .catch((error) => reply(Boom.badRequest(error)));
              });
          }
        }
      ]);

      // Dependencies are registered, continue with next callback.
      next();

    });

    // Plugin is registered, continue with next callback.
    next();

  });

};

// Attach plugin attributes.
plugin.attributes = {
  pkg: require('./package.json')
};

// Expose plugin on module's register property.
exports.register = plugin;
